==> haskell-microlens-aeson-2.3.0.1-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-aeson
version: 2.3.0.1
id: microlens-aeson-2.3.0.1-F3rF5QDWbAK3hng9Mkwjv
key: microlens-aeson-2.3.0.1-F3rF5QDWbAK3hng9Mkwjv
license: MIT
copyright: Copyright (C) 2012 Paul Wilson, (C) 2013 Edward A. Kmett, (C) 2015 Colin Woodbury
maintainer: Colin Woodbury <colingw@gmail.com>
author: Colin Woodbury
homepage: http://github.com/fosskers/microlens-aeson/
synopsis: Law-abiding lenses for Aeson, using microlens.
description:
    Law-abiding lenses for Aeson, using microlens.
category: Numeric
abi: 3a304758b0cd64e0f1e60d0a4c3a9c8e
exposed: True
exposed-modules:
    Lens.Micro.Aeson
hidden-modules: Lens.Micro.Aeson.Internal Paths_microlens_aeson
import-dirs: /usr/lib/ghc-8.6.5/site-local/microlens-aeson-2.3.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/microlens-aeson-2.3.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/microlens-aeson-2.3.0.1
hs-libraries: HSmicrolens-aeson-2.3.0.1-F3rF5QDWbAK3hng9Mkwjv
depends:
    aeson-1.4.3.0-2f2DWYxbnUnFm9iFQHaKmb
    attoparsec-0.13.2.2-1slbQhZI8n0L2sAfK4cuOg base-4.12.0.0
    bytestring-0.10.8.2 deepseq-1.4.4.0
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    microlens-0.4.10-LVgmazyXGvNKvoQElrYSfS
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-microlens-aeson/html/microlens-aeson.haddock
haddock-html: /usr/share/doc/haskell-microlens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-aeson-2.3.0.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-aeson
version: 2.3.0.2
id: microlens-aeson-2.3.0.2-IYGbnKUyXBjB9Z2KHdwnf5
key: microlens-aeson-2.3.0.2-IYGbnKUyXBjB9Z2KHdwnf5
license: MIT
copyright: Copyright (C) 2012 Paul Wilson, (C) 2013 Edward A. Kmett, (C) 2015 Colin Woodbury
maintainer: Colin Woodbury <colin@fosskers.ca>
author: Colin Woodbury
homepage: http://github.com/fosskers/microlens-aeson/
synopsis: Law-abiding lenses for Aeson, using microlens.
description:
    Law-abiding lenses for Aeson, using microlens.
category: Numeric
abi: f2e75157058ef36e9d2c1dfc799fb5d0
exposed: True
exposed-modules:
    Lens.Micro.Aeson
hidden-modules: Lens.Micro.Aeson.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/microlens-aeson-2.3.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/microlens-aeson-2.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/microlens-aeson-2.3.0.2
hs-libraries: HSmicrolens-aeson-2.3.0.2-IYGbnKUyXBjB9Z2KHdwnf5
depends:
    aeson-1.4.3.0-5u6hknCeN6OEP5DlN5W0LL
    attoparsec-0.13.2.2-FR6Av5BO2dBDiw4NtrzSsH base-4.12.0.0
    bytestring-0.10.8.2 deepseq-1.4.4.0
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    microlens-0.4.10-LVgmazyXGvNKvoQElrYSfS
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-microlens-aeson/html/microlens-aeson.haddock
haddock-html: /usr/share/doc/haskell-microlens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
